library digital_ocean_rhinosoft;

import 'dart:typed_data';
import 'package:http/http.dart' as http;
import 'package:http/http.dart';
import 'package:image_picker/image_picker.dart';
import 'dart:convert';

class DigitalOcean {
  static DigitalOcean? _digitalOcean;
  String? url;
  String? projectName;
  String? permission;

  DigitalOcean._(
      {required this.url, required this.projectName, required this.permission});
  static DigitalOcean initializeInstance(
      {required url, required projectName, required permission}) {
    _digitalOcean = DigitalOcean._(
        url: url, projectName: projectName, permission: permission);
    return _digitalOcean!;
  }

  static DigitalOcean getInstance() {
    if (_digitalOcean == null) {
      throw Exception(
          'No instance was initialized please use the method [initializeInstance] somewhere in your application before using [getInstance]');
    }
    return _digitalOcean!;
  }

  Future<List<String>> uploadFiles({
    String? permission,
    required String path,
    required List<String> filesNames,
    required List<Uint8List> data,
  }) async {
    final Map<String, String> headers = {
      'Access-Control-Allow-Origin': '*',
    };
    MultipartRequest request = http.MultipartRequest('POST', Uri.parse(url!));
    request.headers.addAll(headers);
    for (int i = 0; i < filesNames.length; i++) {
      List<int> list = data[i].cast();
      request.files.add(
          http.MultipartFile.fromBytes('file', list, filename: filesNames[i]));
    }
    // permission public-read
    // permission private
    permission ??= this.permission!;
    request.fields.addAll({
      'projectName': projectName!,
      'path': path,
      'permission': permission,
    });
    http.StreamedResponse response = await request.send();
    String converted = await response.stream.bytesToString();
    List<String> links = List.from(json.decode(converted));
    return links;
  }

  Future<String> uploadFile({
    String? permission,
    required String path,
    required String fileName,
    required Uint8List data,
  }) async {
    List<String> links = await uploadFiles(
        path: path,
        data: [data],
        filesNames: [fileName],
        permission: permission);
    return links[0];
  }

  Future uploadImage({
    String? permission,
    required String path,
    required String imageName,
    required XFile image,
  }) async {
    final String fileName =
        imageName + "." + image.mimeType!.substring(image.mimeType!.indexOf('/') + 1);
    final Map<String, String> headers = {
      'Access-Control-Allow-Origin': '*',
    };
    http.MultipartRequest request =
        http.MultipartRequest('POST', Uri.parse(url!));
    request.headers.addAll(headers);
    Uint8List data = await image.readAsBytes();
    List<int> list = data.cast();
    request.files
        .add(http.MultipartFile.fromBytes('file', list, filename: fileName));
    permission ??= this.permission!;

    request.fields.addAll({
      'projectName': projectName!,
      'path': path,
      'permission': permission,
    });
    http.StreamedResponse response = await request.send();
    String converted = await response.stream.bytesToString();
    List<String> links = List.from(json.decode(converted));
    return links[0];
  }
}
