import 'dart:typed_data';

import 'package:digital_ocean_rhinosoft/digital_ocean_rhinosoft.dart';
import 'package:image_picker/image_picker.dart';
import 'package:test/test.dart';

void main() async {
  const String url = '<your server url>';
  const String projectName = '<your project Name>';
  const String permission = 'public-read';
  const String path = '/test';
  String fileName = 'best.yo';
  Uint8List data = Uint8List(10);
  List<String> links = [];
  test("Uploading two small files (10 Bytes)", () async {
    DigitalOcean digitalOcean = DigitalOcean.initializeInstance(
        url: url, projectName: projectName, permission: permission);
    links = await digitalOcean.uploadFiles(
        path: path, filesNames: [fileName, fileName], data: [data, data]);
    expect(links.length, 2);
  }, timeout: const Timeout(Duration(seconds: 2)));
  test("File path is correct", () {
    expect(links[0].contains(path), true);
  }, timeout: const Timeout(Duration(minutes: 10)));
  test("File name is correct", () {
    expect(links[0].contains(fileName), true);
  }, timeout: const Timeout(Duration(milliseconds: 10)));
  test("Link is https", () {
    expect(links[0].startsWith("https://"), true);
  }, timeout: const Timeout(Duration(milliseconds: 10)));

  test("Uploading a big file (10 MB)", () async {
    data = Uint8List(1024 * 1024 * 10);
    fileName = 'bigdata.raw';
    DigitalOcean digitalOcean = DigitalOcean.getInstance();

    digitalOcean = DigitalOcean.initializeInstance(
        url: url, projectName: projectName, permission: permission);
    String link = await digitalOcean.uploadFile(
        path: path, fileName: fileName, data: data);
    expect(link.contains(path), true);
    expect(link.contains(fileName), true);
  }, timeout: const Timeout(Duration(seconds: 30)));
  test("Uploading a dummy image", () async {
    DigitalOcean digitalOcean = DigitalOcean.getInstance();
    fileName = 'image.png';
    XFile image =
        XFile('/home/fox/Pictures/Screenshot from 2021-12-23 10-15-06.png');
    String fileType =
        image.mimeType!.substring(image.mimeType!.indexOf('/') + 1);
    String link = await digitalOcean.uploadImage(
        path: path, imageName: fileName, image: image);
    expect(link.contains(path), true);
    expect(link.contains(fileName), true);
    expect(link.contains(fileType), true);
    expect(link.contains(fileName + "." + fileType), true);
  }, timeout: const Timeout(Duration(seconds: 2)));
}
